@@ -15,7 +15,7 @@ import re
 
 parser_re = re.compile(ur"""\b
     # Latitude direction, first position: one of N, S, NORTH, SOUTH
-    (?P<latdir>NORTH|SOUTH|[NS])?
+    ((?P<latdir>NORTH|SOUTH|[NS])\ ?)?
     # Latitude degrees: two digits 0-90
     (?P<latdeg>([0-8][0-9])|90)
     # Optional space, degree mark, period,
@@ -25,10 +25,10 @@ parser_re = re.compile(ur"""\b
     # Latitude minutes: two digits 0-59
     (?P<latmin>[0-5][0-9])
     # If there was a degree mark before, look for punctuation after the minutes
-    (\ |(?(degmark)('|"|\.|\ MINUTES(,\ )?)))?
+    (\ |(?(degmark)('|"|\ MINUTES(,\ )?)))?
     (
-    # Latitude seconds: two digits 0-59
-    ((?P<latsec>([0-9]|[0-5][0-9]))|
+    # Latitude seconds: two digits
+    ((?P<latsec>(\d{1,2}))|
     # Decimal fraction of minutes
     (?P<latdecsec>\.\d{1,3}))?)
     (?(degmark)("|'|\ SECONDS\ )?)
@@ -37,10 +37,10 @@ parser_re = re.compile(ur"""\b
     (\ ?(?P<latdir2>(?(latdir)|(NORTH|SOUTH|[NS]))))
     # Latitude/longitude delimiter: space, forward slash, comma, or none
     (\ ?[ /]\ ?|,\ )?
-    # Longitude direction, first position: one of N, S, NORTH, SOUTH
-    (?(latdir)(?P<longdir>EAST|WEST|[EW]))
+    # Longitude direction, first position: one of E, W, EAST, WEST
+    (?(latdir)((?P<longdir>EAST|WEST|[EW])\ ?))
     # Longitude degrees: two or three digits
-    (?P<longdeg>\d{2,3})
+    (?P<longdeg>((1(([0-7][0-9]|80))|(0?[0-9][0-9]))))
     # If there was a degree mark before, look for another one here
     (\ |(?(degmark)(\ ?(º|°)\ ?|\.|-|\ DEGREES,\ )))?
     (?(latminsec)   #Only look for minutes and seconds in the longitude
@@ -48,9 +48,9 @@ parser_re = re.compile(ur"""\b
     # Longitude minutes: two digits
     (?P<longmin>[0-5][0-9])
     # If there was a degree mark before, look for punctuation after the minutes
-    (\ |(?(degmark)('|"|\.|\ MINUTES(,\ )?)))?
-    # Longitude seconds: two digits 0-59
-    ((?P<longsec>([0-9][0-9]))|
+    (\ |(?(degmark)('|"|\ MINUTES(,\ )?)))?
+    # Longitude seconds: two digits
+    ((?P<longsec>(\d{1,2}))|
     # Decimal fraction of minutes
     (?P<longdecsec>\.\d{1,3}))?)
     (?(degmark)("|'|\ SECONDS\ )?)
